@@ -183,8 +183,8 @@ def get_single_line_text_input_dialog(chars, label_width, title, ok_button_text,
                                       label, default_text):
     dialog = Gtk.Dialog(title, None,
                             Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                            (_("Cancel"), Gtk.ResponseType.REJECT,
-                            ok_button_text, Gtk.ResponseType.OK))
+                            (_("Cancel"), Gtk.ResponseType.CANCEL,
+                            ok_button_text, Gtk.ResponseType.ACCEPT))
 
     entry = Gtk.Entry()
     entry.set_width_chars(chars)
