@@ -26,6 +26,9 @@ Handles edit mode setting.
 from gi.repository import Gdk
 
 import copy
+import hashlib
+import os
+import shutil
 
 import appconsts
 import audiosync
@@ -42,11 +45,12 @@ import edit
 import editorstate
 from editorstate import current_sequence
 from editorstate import PLAYER
+from editorstate import PROJECT
 from editorstate import timeline_visible
 from editorstate import EDIT_MODE
 import editorpersistance
 import gui
-import guicomponents
+import guipopoverclip
 import kftoolmode
 import medialog
 import modesetting
@@ -57,15 +61,16 @@ import syncsplitevent
 import tlinewidgets
 import trimmodes
 import updater
+import userfolders
 
 
 # functions are monkeypatched in at app.py 
 display_clip_menu_pop_up = None
 compositor_menu_item_activated = None
-
+set_compositor_data = None
 
 # ----------------------------- module funcs
-def do_clip_insert(track, new_clip, tline_pos):
+def do_clip_insert(track, new_clip, tline_pos, use_clip_in=False):
     index = _get_insert_index(track, tline_pos)
 
     # Can't put audio media on video track 
@@ -76,26 +81,36 @@ def do_clip_insert(track, new_clip, tline_pos):
 
     movemodes.clear_selected_clips()
     
+    clip_in = new_clip.mark_in
+    clip_out = new_clip.mark_out
+    if use_clip_in == True:
+        clip_in = new_clip.clip_in
+        clip_out = new_clip.clip_out
+    
     # Do edit
     data = {"track":track,
             "clip":new_clip,
             "index":index,
-            "clip_in":new_clip.mark_in,
-            "clip_out":new_clip.mark_out}
+            "clip_in":clip_in,
+            "clip_out":clip_out}
     action = edit.insert_action(data)
     action.do_edit()
     
     updater.display_tline_cut_frame(track, index)
 
-def do_multiple_clip_insert(track, clips, tline_pos):
+def do_multiple_clip_insert(track, clips, tline_pos, use_as_action_build_func_for_paste=False):
     index = _get_insert_index(track, tline_pos)
     
+    if use_as_action_build_func_for_paste == True:
+        # For this use case there happens a cut before the insert is done.
+        index += 1
+    
     # Can't put audio media on video track
     for new_clip in clips:
         if isinstance(new_clip, int):
             continue
         if ((new_clip.media_type == appconsts.AUDIO)
-           and (track.type == appconsts.VIDEO)):        
+           and (track.type == appconsts.VIDEO)):
             _display_no_audio_on_video_msg(track)
             return
 
@@ -106,6 +121,8 @@ def do_multiple_clip_insert(track, clips, tline_pos):
             "clips":clips,
             "index":index}
     action = edit.insert_multiple_action(data)
+    if use_as_action_build_func_for_paste == True:
+        return action
     action.do_edit()
 
     updater.display_tline_cut_frame(track, index)
@@ -113,7 +130,7 @@ def do_multiple_clip_insert(track, clips, tline_pos):
 def  _attempt_dnd_overwrite(track, clip, frame):
     # Can't put audio media on video track 
     if ((clip.media_type == appconsts.AUDIO)
-       and (track.type == appconsts.VIDEO)):        
+       and (track.type == appconsts.VIDEO)):
         return
 
     # Dropping on first available frame after last clip is append 
@@ -305,7 +322,10 @@ def tline_canvas_mouse_pressed(event, frame):
                     return
             if event.button == 3:
                 compositormodes.set_compositor_selected(hit_compositor)
-                guicomponents.display_compositor_popup_menu(event, hit_compositor,
+                set_compositor_data(hit_compositor)
+                guipopoverclip.compositor_popover_menu_show(gui.tline_canvas.widget,
+                                                            event.x, event.y, 
+                                                            hit_compositor, 
                                                             compositor_menu_item_activated)
                 return
             elif event.button == 2:
@@ -526,8 +546,20 @@ def tline_media_drop(drag_data, x, y, use_marks=False):
     # Create new clip.
     if media_file.type != appconsts.PATTERN_PRODUCER:
         if media_file.container_data == None:
-            # Standard clips
-            new_clip = current_sequence().create_file_producer_clip(media_file.path, media_file.name, False, media_file.ttl)
+            if media_file.titler_data == None:
+                # Standard clips
+                new_clip = current_sequence().create_file_producer_clip(media_file.path, media_file.name, False, media_file.ttl)
+            else:
+                # Title clips
+                # Create copy of graphic and titler data for clip so that all clips created 
+                # from the same media item can be edited independently.
+                md_str = hashlib.md5(str(os.urandom(32)).encode('utf-8')).hexdigest() + ".png"
+                clip_graphic_path = userfolders.get_render_dir() + md_str
+                shutil.copyfile(media_file.path, clip_graphic_path)
+                titler_data = copy.deepcopy(media_file.titler_data)
+
+                new_clip = current_sequence().create_file_producer_clip(clip_graphic_path, media_file.name, False, media_file.ttl)
+                new_clip.titler_data = titler_data
         else:
             # Container clips, create new container_data object and generate uuid for clip so it gets it own folder in.$XML_DATA/.../container_clips
             new_clip = current_sequence().create_file_producer_clip(media_file.path, media_file.name, False, media_file.ttl)
@@ -535,15 +567,16 @@ def tline_media_drop(drag_data, x, y, use_marks=False):
             new_clip.container_data.generate_clip_id()
     else:
         new_clip = current_sequence().create_pattern_producer(media_file)
-            
+
     # Set clip in and out
     if use_marks == False:
+        # This probably dead code, use_marks=False always?
         new_clip.mark_in = 0
         new_clip.mark_out = new_clip.get_length() - 1 # - 1 because out is mark_out inclusive
 
         if media_file.type == appconsts.IMAGE_SEQUENCE:
             new_clip.mark_out = media_file.length
-    else:    
+    else: 
         # Media types that do not have length determined by content.
         if new_clip.media_type == appconsts.IMAGE or new_clip.media_type == appconsts.PATTERN_PRODUCER:
 
@@ -575,6 +608,16 @@ def tline_media_drop(drag_data, x, y, use_marks=False):
                 if media_file.type == appconsts.IMAGE_SEQUENCE:
                     new_clip.mark_out = media_file.length
 
+    # Images fom media panel get bin default length.
+    use_clip_in = False
+    if dnd.drag_source != dnd.SOURCE_MONITOR_WIDGET and  new_clip.media_type == appconsts.IMAGE:
+        default_grfx_length = PROJECT().get_current_bin_graphics_default_length()
+        in_fr = (new_clip.get_length() - 1) // 2 - (default_grfx_length // 2)
+        out_fr = in_fr + default_grfx_length - 1
+        new_clip.clip_in = in_fr
+        new_clip.clip_out = out_fr
+        use_clip_in = True
+        
     # Non-insert DND actions
     if editorpersistance.prefs.dnd_action == appconsts.DND_OVERWRITE_NON_V1:
         if track.id != current_sequence().first_video_track().id:
@@ -590,7 +633,7 @@ def tline_media_drop(drag_data, x, y, use_marks=False):
             gui.media_list_view.clear_selection()
             return
             
-    do_clip_insert(track, new_clip, frame)
+    do_clip_insert(track, new_clip, frame, use_clip_in)
     gui.media_list_view.clear_selection()
                 
     maybe_autorender_plugin(new_clip)
