@@ -29,7 +29,9 @@ import appconsts
 import atomicfile
 import mltprofiles
 import userfolders
-import utils
+import utils # this needs to also go to not load Gtk for background rendering process
+import usbhid
+
 
 PREFS_DOC = "prefs"
 RECENT_DOC = "recent"
@@ -38,6 +40,8 @@ MAX_RECENT_PROJS = 15
 UNDO_STACK_DEFAULT = 30
 UNDO_STACK_MIN = 10
 UNDO_STACK_MAX = 100
+FILTER_SELECT_WIDTH_MIN = 220
+FILTER_SELECT_WIDTH_MAX = 350
 
 GLASS_STYLE = 0
 SIMPLE_STYLE = 1
@@ -171,30 +175,24 @@ def get_recent_projects():
     return proj_list
 
 def update_prefs_from_widgets(widgets_tuples_tuple):
-    # Aug-2019 - SvdB - BB - Replace double_track_hights by double_track_hights
-    # Unpack widgets
-    # Toolbar preferences panel for free elements and order
-    gen_opts_widgets, edit_prefs_widgets, playback_prefs_widgets, view_prefs_widgets, performance_widgets = widgets_tuples_tuple
-    # End of Toolbar preferences panel for free elements and order
-
-    # Aug-2019 - SvdB - AS - added autosave_combo
+    gen_opts_widgets, edit_prefs_widgets, playback_prefs_widgets, view_prefs_widgets, performance_widgets, jog_shuttle_widgets = widgets_tuples_tuple
+    
     default_profile_combo, open_in_last_opened_check, open_in_last_rendered_check, undo_max_spin, load_order_combo, \
-        autosave_combo, render_folder_select, disk_cache_warning_combo = gen_opts_widgets
+    autosave_combo, render_folder_select, disk_cache_warning_combo = gen_opts_widgets
 
-    # Jul-2016 - SvdB - Added play_pause_button
-    # Apr-2017 - SvdB - Added ffwd / rev values
     gfx_length_spin, cover_delete, mouse_scroll_action, hide_file_ext_button, \
     hor_scroll_dir, effects_editor_clip_load, auto_render_plugins, dnd_action = edit_prefs_widgets
 
     auto_center_check, play_pause_button, timeline_start_end_button, auto_center_on_updown, \
-    ffwd_rev_shift_spin, ffwd_rev_ctrl_spin, ffwd_rev_caps_spin, follow_move_range, loop_clips = playback_prefs_widgets
+    ffwd_rev_shift_spin, ffwd_rev_caps_spin, follow_move_range, loop_clips = playback_prefs_widgets
     
     force_language_combo, disp_splash, window_mode_combo, full_names, double_track_hights, \
-    top_row_layout, layout_monitor = view_prefs_widgets
+    top_row_layout, layout_monitor, filter_select_width_spin = view_prefs_widgets
 
-    # Jan-2017 - SvdB
     perf_render_threads, perf_drop_frames = performance_widgets
 
+    usbhid_enabled_check, usbhid_config_combo = jog_shuttle_widgets
+
     global prefs
     prefs.open_in_last_opended_media_dir = open_in_last_opened_check.get_active()
     prefs.remember_last_render_dir = open_in_last_rendered_check.get_active()
@@ -206,7 +204,6 @@ def update_prefs_from_widgets(widgets_tuples_tuple):
     prefs.default_grfx_length = int(gfx_length_spin.get_adjustment().get_value())
     prefs.trans_cover_delete = cover_delete.get_active()
 
-    # Jul-2016 - SvdB - For play/pause button
     prefs.play_pause = play_pause_button.get_active()
 # ------------------------------ timeline_start_end_button
     prefs.timeline_start_end = timeline_start_end_button.get_active()
@@ -215,9 +212,7 @@ def update_prefs_from_widgets(widgets_tuples_tuple):
     prefs.mouse_scroll_action_is_zoom = (mouse_scroll_action.get_active() == 0)
     prefs.scroll_horizontal_dir_up_forward = (hor_scroll_dir.get_active() == 0)
     prefs.single_click_effects_editor_load = (effects_editor_clip_load.get_active() == 1)
-    # Apr-2017 - SvdB - ffwd / rev values
     prefs.ffwd_rev_shift = int(ffwd_rev_shift_spin.get_adjustment().get_value())
-    prefs.ffwd_rev_ctrl = int(ffwd_rev_ctrl_spin.get_adjustment().get_value())
     prefs.ffwd_rev_caps = int(ffwd_rev_caps_spin.get_adjustment().get_value())
     prefs.loop_clips = loop_clips.get_active()
 
@@ -226,24 +221,36 @@ def update_prefs_from_widgets(widgets_tuples_tuple):
     prefs.display_splash_screen = disp_splash.get_active()
 
     prefs.global_layout = window_mode_combo.get_active() + 1 # +1 'cause values are 1 and 2
-    # Jan-2017 - SvdB
     prefs.perf_render_threads = int(perf_render_threads.get_adjustment().get_value())
     prefs.perf_drop_frames = perf_drop_frames.get_active()
-    # Feb-2017 - SvdB - for full file names
     prefs.show_full_file_names = full_names.get_active()
     prefs.center_on_arrow_move = auto_center_on_updown.get_active()
     prefs.double_track_hights = (double_track_hights.get_active() == 1)
     prefs.playback_follow_move_tline_range = follow_move_range.get_active()
     prefs.top_row_layout = top_row_layout.get_active()
-    # Aug-2019 - SvdB - AS
     prefs.auto_save_delay_value_index = autosave_combo.get_active()
     prefs.layout_display_index = layout_monitor.get_active()
     if len(render_folder_select.get_filenames()) != 0:
         prefs.default_render_directory = render_folder_select.get_filename()
     prefs.disk_space_warning = disk_cache_warning_combo.get_active()
     prefs.auto_render_media_plugins = auto_render_plugins.get_active()
+    # --------------------------------- USB HID
+    prefs.usbhid_enabled = usbhid_enabled_check.get_active()
+    usbhid_config_index = usbhid_config_combo.get_active()
+    if usbhid_config_index == 0:
+        prefs.usbhid_config = None
+    else:
+        usbhid_config_metadata_list = usbhid.get_usb_hid_device_config_metadata_list()
+        if len(usbhid_config_metadata_list) >= (usbhid_config_index - 1):
+            # index 0 in the combo box is "None", the -1 offsets the zero-based index from the list
+            # with the 1-based index from the combo box in the preferences GUI
+            prefs.usbhid_config = usbhid_config_metadata_list[usbhid_config_index - 1].device_config_name
+        else:
+            prefs.usbhid_config = None
+    # --------------------------------- USB HID END
     prefs.dnd_action = dnd_action.get_active()
-    
+    prefs.filter_select_width = int(filter_select_width_spin.get_value())
+
 def get_graphics_default_in_out_length():
     in_fr = int(15000/2) - int(prefs.default_grfx_length/2)
     out_fr = in_fr + int(prefs.default_grfx_length) - 1 # -1, out inclusive
@@ -319,8 +326,8 @@ class EditorPreferences:
         self.show_full_file_names = False
         self.center_on_arrow_move = True
         # Apr-2017 - SvdB - Using these values we maintain the original hardcoded speed.
-        self.ffwd_rev_shift = 1
-        self.ffwd_rev_ctrl = 10
+        self.ffwd_rev_shift = 10
+        self.ffwd_rev_ctrl = 10 # DEPRECATED, CTRL + arrow now does 10 fps slowmo playback
         self.ffwd_rev_caps = 1
         self.shortcuts = "flowblade.xml"
         self.double_track_hights = False
@@ -364,4 +371,7 @@ class EditorPreferences:
         self.auto_expand_tracks = True
         self.quick_effects = None
         self.auto_render_media_plugins = True
+        self.usbhid_enabled = False
+        self.usbhid_config = None
         self.zoom_to_playhead = True
+        self.filter_select_width = 220
