@@ -59,8 +59,9 @@ KEYFRAME_EDITOR_RELEASE = "keyframe_editor_release"         # HACK, HACK. used t
 COLOR_SELECT = "color_select"                               # Gtk.ColorButton
 GEOMETRY_EDITOR = "geometry_editor"                         # keyframeeditor.GeometryEditor
 FILTER_RECT_GEOM_EDITOR = "filter_rect_geometry_editor"     # keyframeeditor.FilterRectGeometryEditor
+FILTER_ROTATION_GEOM_EDITOR = "filter_rotation_geometry_editor" # Creates a single editor for multiple geometry values for using in filter 
 WIPE_SELECT = "wipe_select"                                 # Gtk.Combobox with options from mlttransitions.wipe_lumas, possible to select luma from file system
-FILTER_WIPE_SELECT = "filter_wipe_select"                   #  Gtk.Combobox with options from mlttransitions.wipe_lumas
+FILTER_WIPE_SELECT = "filter_wipe_select"                   # Gtk.Combobox with options from mlttransitions.wipe_lumas
 COMBO_BOX_OPTIONS = "cbopts"                                # List of options for combo box editor displayed to user
 LADSPA_SLIDER = "ladspa_slider"                             # Gtk.HScale, does ladspa update for release changes(disconnect, reconnect)
 CLIP_FRAME_SLIDER = "clip_frame_slider"                     # Gtk.HScale, range 0 - clip length in frames
@@ -74,13 +75,17 @@ FILE_TYPES = "file_types"                                   # list of files type
 FADE_LENGTH = "fade_length"                                 # Autofade compositors fade length
 TEXT_ENTRY = "text_entry"                                   # Text editor
 ROTOMASK = "rotomask"                                       # Displays info and launches rotomask window
+NO_KF_RECT = "no_keyframes_rect"                            # keyframeeditor.GeometryNoKeyframes, no keyframes here, machinery for creating this type GUI editors just assumes keyframes
 NO_EDITOR = "no_editor"                                     # No editor displayed for property
 
 COMPOSITE_EDITOR_BUILDER = "composite_properties"           # Creates a single row editor for multiple properties of composite transition
 REGION_EDITOR_BUILDER = "region_properties"                 # Creates a single row editor for multiple properties of region transition
 ROTATION_GEOMETRY_EDITOR_BUILDER = "rotation_geometry_editor" # Creates a single editor for multiple geometry values
-
-
+INFOANDTIPS = "infotips"                                    # Displays link to docs Info & Tips page 
+ANALYZE_STABILIZE = "analyzestabilize"                      # Launches stabilizing analyzis for clip
+ANALYZE_MOTION = "analyzemotion"                            # Launches motion tracking analyzis for clip
+APPLY_MOTION = "applymotion"                                # Applies motion tracking as source image movement.
+APPLY_FILTER_MASK_MOTION = "applyfiltermaskmotion"          # Applies motion tracking as filter mask.
 SCALE_DIGITS = "scale_digits"                               # Number of decimal digits displayed in a widget
 
 # We need to use globals to change slider -> kf editor and back because the data does not (can not) exist anywhere else. FilterObject.properties are just tuples and EditableProperty objects
@@ -96,7 +101,6 @@ def _p(name):
     except KeyError:
         return name
 
-
 def get_editor_row(editable_property):
     """
     Returns GUI component to edit provided editable property.
@@ -125,72 +129,29 @@ def get_transition_extra_editor_rows(compositor, editable_properties):
 
     return rows
 
-def get_filter_extra_editor_rows(filt, editable_properties):
+def get_filter_extra_editor_rows(filt, editable_properties, track, clip_index):
     """
     Returns list of extraeditors GUI components.
     """
     extra_editors = filt.info.extra_editors
     rows = []
     for editor_name in extra_editors:
-        try:
-            create_func = EDITOR_ROW_CREATORS[editor_name]
-            editor_row = create_func(filt, editable_properties)
-            rows.append(editor_row)
-        except KeyError:
-            print("get_filter_extra_editor_rows fail with:" + editor_name)
+        create_func = EDITOR_ROW_CREATORS[editor_name]
+        editor_row = create_func(filt, editable_properties, editor_name, track, clip_index)
+        
+        rows.append(editor_row)
 
     return rows
 
-def create_editable_property_for_affine_blend(clip, editable_properties):
-    # Build a custom object that duck types for TransitionEditableProperty 
-    # to be used in editor propertyeditor.RotatingGeometryEditor.
-    ep = utils.EmptyClass()
-    # pack real properties to go
-    ep.x = [ep for ep in editable_properties if ep.name == "x"][0]
-    ep.y = [ep for ep in editable_properties if ep.name == "y"][0]
-    ep.x_scale = [ep for ep in editable_properties if ep.name == "x scale"][0]
-    ep.y_scale = [ep for ep in editable_properties if ep.name == "y scale"][0]
-    ep.rotation = [ep for ep in editable_properties if ep.name == "rotation"][0]
-    ep.opacity = [ep for ep in editable_properties if ep.name == "opacity"][0]
-    # Screen width and height are needed for frei0r conversions
-    ep.profile_width = current_sequence().profile.width()
-    ep.profile_height = current_sequence().profile.height()
-    # duck type methods, using opacity is not meaningful, any property with clip member could do
-    ep.get_clip_tline_pos = lambda : ep.opacity.clip.clip_in # clip is compositor, compositor in and out points are straight in timeline frames
-    ep.get_clip_length = lambda : ep.opacity.clip.clip_out - ep.opacity.clip.clip_in + 1
-    ep.get_input_range_adjustment = lambda : Gtk.Adjustment(value=float(100), lower=float(0), upper=float(100), step_increment=float(1))
-    ep.get_display_name = lambda : "Opacity"
-    ep.get_pixel_aspect_ratio = lambda : (float(current_sequence().profile.sample_aspect_num()) / current_sequence().profile.sample_aspect_den())
-    ep.get_in_value = lambda out_value : out_value # hard coded for opacity 100 -> 100 range
-    ep.write_out_keyframes = lambda w_kf : propertyparse.rotating_ge_write_out_keyframes(ep, w_kf)
-    ep.update_prop_value = lambda : propertyparse.rotating_ge_update_prop_value(ep) # This is needed to get good update after adding kfs with fade buttons, iz all kinda fugly
-                                                                            # We need this to reinit GUI components after programmatically added kfs.
-    # duck type members
-    x_tokens = ep.x.value.split(";")
-    y_tokens = ep.y.value.split(";")
-    x_scale_tokens = ep.x_scale.value.split(";")
-    y_scale_tokens = ep.y_scale.value.split(";")
-    rotation_tokens = ep.rotation.value.split(";")
-    opacity_tokens = ep.opacity.value.split(";")
+def get_non_mlt_property_editor_row(non_mlt_editable_property, editor):
+    """
+    Returns GUI component to edit provided non-mlt editable property.
+    """
+    create_func = EDITOR_ROW_CREATORS[editor]
+    row = create_func(non_mlt_editable_property)
+    row.set_margin_top(4)
+    return row
     
-    value = ""
-    for i in range(0, len(x_tokens)): # these better match, same number of keyframes for all values, or this will not work
-        frame, x, kf_type =  propertyparse._get_roto_geom_frame_value(x_tokens[i])
-        frame, y, kf_type =  propertyparse._get_roto_geom_frame_value(y_tokens[i])
-        frame, x_scale, kf_type =  propertyparse._get_roto_geom_frame_value(x_scale_tokens[i])
-        frame, y_scale, kf_type =  propertyparse._get_roto_geom_frame_value(y_scale_tokens[i])
-        frame, rotation, kf_type =  propertyparse._get_roto_geom_frame_value(rotation_tokens[i])
-        frame, opacity, kf_type =  propertyparse._get_roto_geom_frame_value(opacity_tokens[i])
-
-        eq_str = propertyparse._get_eq_str(kf_type)
-
-        frame_str = str(frame) + eq_str + str(x) + ":" + str(y) + ":" + str(x_scale) + ":" + str(y_scale) + ":" + str(rotation) + ":" + str(opacity)
-        value += frame_str + ";"
-
-    ep.value = value.strip(";")
-
-    return ep
-
 
     
 # ------------------------------------------------- gui builders
@@ -860,9 +821,9 @@ def _get_file_select_editor(editable_property):
     editor_row.pack_start(file_select_button, False, False, 0)
 
     dialog.connect('response', editable_property.dialog_response_callback)
-    
+
     return editor_row
-    
+
 def _get_image_file_select_editor(editable_property):
     """
     Returns GUI component for selecting image producing file
@@ -941,10 +902,59 @@ def _compositor_editor_force_combo_box_callback(combo_box, data):
         progressive.write_value("1")
 
 def _create_rotion_geometry_editor(clip, editable_properties):   
-    ep = create_editable_property_for_affine_blend(clip, editable_properties)
+    ep = create_rotating_geometry_editor_property(clip, editable_properties)
     kf_edit = keyframeeditor.RotatingGeometryEditor(ep, False)
     return kf_edit
 
+def create_rotating_geometry_editor_property(clip, editable_properties):
+    # Build a custom object that duck types for TransitionEditableProperty 
+    # to be used in editor keyframeeditor.RotatingGeometryEditor.
+    ep = utils.EmptyClass()
+    # pack real properties to go
+    ep.x = [ep for ep in editable_properties if ep.name == "x"][0]
+    ep.y = [ep for ep in editable_properties if ep.name == "y"][0]
+    ep.x_scale = [ep for ep in editable_properties if ep.name == "x scale"][0]
+    ep.y_scale = [ep for ep in editable_properties if ep.name == "y scale"][0]
+    ep.rotation = [ep for ep in editable_properties if ep.name == "rotation"][0]
+    ep.opacity = [ep for ep in editable_properties if ep.name == "opacity"][0]
+    # Screen width and height are needed for frei0r conversions
+    ep.profile_width = current_sequence().profile.width()
+    ep.profile_height = current_sequence().profile.height()
+    # duck type methods, using opacity is not meaningful, any property with clip member could do
+    ep.get_clip_tline_pos = lambda : ep.opacity.clip.clip_in # clip is compositor, compositor in and out points are straight in timeline frames
+    ep.get_clip_length = lambda : ep.opacity.clip.clip_out - ep.opacity.clip.clip_in + 1
+    ep.get_input_range_adjustment = lambda : Gtk.Adjustment(value=float(100), lower=float(0), upper=float(100), step_increment=float(1))
+    ep.get_display_name = lambda : "Opacity"
+    ep.get_pixel_aspect_ratio = lambda : (float(current_sequence().profile.sample_aspect_num()) / current_sequence().profile.sample_aspect_den())
+    ep.get_in_value = lambda out_value : out_value # hard coded for opacity 100 -> 100 range
+    ep.write_out_keyframes = lambda w_kf : propertyparse.rotating_ge_write_out_keyframes(ep, w_kf)
+    ep.update_prop_value = lambda : propertyparse.rotating_ge_update_prop_value(ep) # This is needed to get good update after adding kfs with fade buttons, iz all kinda fugly
+                                                                                    # We need this to reinit GUI components after programmatically added kfs.
+    x_tokens = ep.x.value.split(";")
+    y_tokens = ep.y.value.split(";")
+    x_scale_tokens = ep.x_scale.value.split(";")
+    y_scale_tokens = ep.y_scale.value.split(";")
+    rotation_tokens = ep.rotation.value.split(";")
+    opacity_tokens = ep.opacity.value.split(";")
+    
+    value = ""
+    for i in range(0, len(x_tokens)): # these better match, same number of keyframes for all values, or this will not work
+        frame, x, kf_type = propertyparse._get_roto_geom_frame_value(x_tokens[i])
+        frame, y, kf_type = propertyparse._get_roto_geom_frame_value(y_tokens[i])
+        frame, x_scale, kf_type = propertyparse._get_roto_geom_frame_value(x_scale_tokens[i])
+        frame, y_scale, kf_type = propertyparse._get_roto_geom_frame_value(y_scale_tokens[i])
+        frame, rotation, kf_type = propertyparse._get_roto_geom_frame_value(rotation_tokens[i])
+        frame, opacity, kf_type = propertyparse._get_roto_geom_frame_value(opacity_tokens[i])
+
+        eq_str = propertyparse._get_eq_str(kf_type)
+
+        frame_str = str(frame) + eq_str + str(x) + ":" + str(y) + ":" + str(x_scale) + ":" + str(y_scale) + ":" + str(rotation) + ":" + str(opacity)
+        value += frame_str + ";"
+
+    ep.value = value.strip(";")
+
+    return ep
+
 def _create_region_editor(clip, editable_properties):
     aligned = [ep for ep in editable_properties if ep.name == "composite.aligned"][0]
     distort = [ep for ep in editable_properties if ep.name == "composite.distort"][0]
@@ -977,7 +987,7 @@ def _create_region_editor(clip, editable_properties):
     hbox.pack_start(guiutils.get_pad_label(3, 5), False, False, 0)
     return hbox
 
-def _create_color_grader(filt, editable_properties):
+def _create_color_grader(filt, editable_properties, editor_name, track, clip_index):
     color_grader = extraeditors.ColorGrader(editable_properties)
 
     vbox = Gtk.VBox(False, 4)
@@ -990,7 +1000,10 @@ def _create_color_grader(filt, editable_properties):
 def _get_filter_rect_geom_editor(ep):
     return keyframeeditor.FilterRectGeometryEditor(ep)
 
-def _create_crcurves_editor(filt, editable_properties):
+def _get_no_kf_rect_geom_editor(ep):
+    return keyframeeditor.GeometryNoKeyframes(ep)
+
+def _create_crcurves_editor(filt, editable_properties, editor_name, track, clip_index):
     curves_editor = extraeditors.CatmullRomFilterEditor(editable_properties)
 
     vbox = Gtk.VBox(False, 4)
@@ -999,7 +1012,25 @@ def _create_crcurves_editor(filt, editable_properties):
     vbox.no_separator = True
     return vbox
 
-def _create_colorbox_editor(filt, editable_properties):
+def _create_filter_roto_geom_editor(filt, editable_properties, editor_name, track, clip_index):
+    clip, filter_index, prop, property_index, args_str = editable_properties[0].used_create_params
+
+    kf_editable_property = propertyedit.KeyFrameFilterRotatingGeometryProperty(
+                                editable_properties[0].used_create_params, 
+                                editable_properties,
+                                track, 
+                                clip_index)
+
+    kf_edit_geom_editor = keyframeeditor.FilterRotatingGeometryEditor(kf_editable_property)
+
+    vbox = Gtk.VBox(False, 4)
+    vbox.pack_start(kf_edit_geom_editor, False, False, 0)
+    vbox.pack_start(Gtk.Label(), True, True, 0)
+    vbox.no_separator = True
+    vbox.kf_edit_geom_editor = kf_edit_geom_editor
+    return vbox
+
+def _create_colorbox_editor(filt, editable_properties, editor_name, track, clip_index):
     colorbox_editor = extraeditors.ColorBoxFilterEditor(editable_properties)
     
     vbox = Gtk.VBox(False, 4)
@@ -1008,7 +1039,66 @@ def _create_colorbox_editor(filt, editable_properties):
     vbox.no_separator = True
     return vbox
 
-def _create_color_lgg_editor(filt, editable_properties):
+def _create_anylaze_stabile_editor(filt, editable_properties, editor_name, track, clip_index):
+    analyze_editor = extraeditors.AnalyzeStabilizeFilterEditor(filt, editable_properties)
+    
+    hbox = Gtk.HBox(False, 4)
+    hbox.pack_start(Gtk.Label(), True, True, 0)
+    hbox.pack_start(analyze_editor.widget, False, False, 0)
+    hbox.no_separator = True
+    return hbox
+
+def _create_anylaze_motion_editor(filt, editable_properties, editor_name, track, clip_index):
+    analyze_editor = extraeditors.AnalyzeMotionTrackingFilterEditor(filt, editable_properties)
+    
+    hbox = Gtk.HBox(False, 4)
+    hbox.pack_start(Gtk.Label(), True, True, 0)
+    hbox.pack_start(analyze_editor.widget, False, False, 0)
+    hbox.no_separator = True
+    return hbox
+
+def _create_apply_motion_editor(filt, editable_properties, editor_name, track, clip_index):
+    filter_index = editable_properties[0].filter_index
+    clip = editable_properties[0].clip
+    non_mlt_properties = propertyedit.get_non_mlt_editable_properties(clip, filt, filter_index, track, clip_index)
+    xoff_prop = [ep for ep in non_mlt_properties if ep.name == "xoff"][0]
+    xoff_prop.write_adjustment_values = True
+    xoff_prop_editor = get_non_mlt_property_editor_row(xoff_prop, LADSPA_SLIDER)
+    yoff_prop = [ep for ep in non_mlt_properties if ep.name == "yoff"][0]
+    yoff_prop.write_adjustment_values = True
+    yoff_prop_editor = get_non_mlt_property_editor_row(yoff_prop, LADSPA_SLIDER)
+    interpretation_prop = [ep for ep in non_mlt_properties if ep.name == "interpretation"][0]
+    interpretation_prop_editor = get_non_mlt_property_editor_row(interpretation_prop, COMBO_BOX)
+    size_prop = [ep for ep in non_mlt_properties if ep.name == "size"][0]
+    size_prop_editor = get_non_mlt_property_editor_row(size_prop, COMBO_BOX)
+    
+    editor = extraeditors.ApplyMotionTrackingFilterEditor(filt, editable_properties, [interpretation_prop_editor, xoff_prop_editor, yoff_prop_editor, size_prop_editor], non_mlt_properties)
+    hbox = Gtk.HBox(False, 4)
+    hbox.pack_start(editor.widget, True, True, 0)
+
+    return hbox
+
+def _create_apply_filter_mask_motion_editor(filt, editable_properties, editor_name, track, clip_index):
+    filter_index = editable_properties[0].filter_index
+    clip = editable_properties[0].clip
+    non_mlt_properties = propertyedit.get_non_mlt_editable_properties(clip, filt, filter_index, track, clip_index)
+    xoff_prop = [ep for ep in non_mlt_properties if ep.name == "xoff"][0]
+    xoff_prop.write_adjustment_values = True
+    xoff_prop_editor = get_non_mlt_property_editor_row(xoff_prop, LADSPA_SLIDER)
+    yoff_prop = [ep for ep in non_mlt_properties if ep.name == "yoff"][0]
+    yoff_prop.write_adjustment_values = True
+    yoff_prop_editor = get_non_mlt_property_editor_row(yoff_prop, LADSPA_SLIDER)
+    scale_prop = [ep for ep in non_mlt_properties if ep.name == "scale"][0]
+    scale_prop.write_adjustment_values = True
+    scale_prop_editor = get_non_mlt_property_editor_row(scale_prop, LADSPA_SLIDER)
+    
+    editor = extraeditors.FilterMaskApplyMotionTrackingEditor(filt, editable_properties, [xoff_prop_editor, yoff_prop_editor, scale_prop_editor], non_mlt_properties)
+    hbox = Gtk.HBox(False, 4)
+    hbox.pack_start(editor.widget, True, True, 0)
+
+    return hbox
+
+def _create_color_lgg_editor(filt, editable_properties, editor_name, track, clip_index):
     color_lgg_editor = extraeditors.ColorLGGFilterEditor(editable_properties)
     vbox = Gtk.VBox(False, 4)
     vbox.pack_start(color_lgg_editor.widget, False, False, 0)
@@ -1016,7 +1106,7 @@ def _create_color_lgg_editor(filt, editable_properties):
     vbox.no_separator = True
     return vbox
 
-def _create_rotomask_editor(filt, editable_properties):
+def _create_rotomask_editor(filt, editable_properties, editor_name, track, clip_index):
 
     property_editor_widgets_create_func = lambda: _create_rotomask_property_editor_widgets(editable_properties)
 
@@ -1046,6 +1136,22 @@ def _create_rotomask_editor(filt, editable_properties):
     vbox.no_separator = True
     return vbox
 
+def _create_infotips_editor(filt, editable_properties, editor_name, track, clip_index):
+    
+    args_str = filt.info.extra_editors_args[editor_name]
+    args = propertyparse.args_string_to_args_dict(args_str)
+    header_name = args["header"].replace("!", " ")
+    link_text = _("Info & tips available under heading '{}'").format(header_name)     
+    uri = "file://" + respaths.INFO_TIPS_DOC
+
+    infotips_editor = extraeditors.InfoAndTipsEditor(uri, link_text)
+
+    hbox = Gtk.VBox(False, 4)
+    hbox.pack_start(infotips_editor.widget, False, False, 0)
+    hbox.pack_start(Gtk.Label(), True, True, 0)
+    hbox.no_separator = False
+    return hbox
+
 def _roto_lauch_pressed(filt, editable_properties, property_editor_widgets_create_func, value_labels):
     show_rotomask_func(filt, editable_properties, property_editor_widgets_create_func, value_labels)
 
@@ -1216,12 +1322,30 @@ EDITOR_ROW_CREATORS = { \
     COMPOSITE_EDITOR_BUILDER: lambda comp, editable_properties: _create_composite_editor(comp, editable_properties),
     REGION_EDITOR_BUILDER: lambda comp, editable_properties: _create_region_editor(comp, editable_properties),
     ROTATION_GEOMETRY_EDITOR_BUILDER: lambda comp, editable_properties: _create_rotion_geometry_editor(comp, editable_properties),
-    COLOR_CORRECTOR: lambda filt, editable_properties: _create_color_grader(filt, editable_properties),
-    CR_CURVES: lambda filt, editable_properties:_create_crcurves_editor(filt, editable_properties),
-    COLOR_BOX: lambda filt, editable_properties:_create_colorbox_editor(filt, editable_properties),
-    COLOR_LGG: lambda filt, editable_properties:_create_color_lgg_editor(filt, editable_properties),
-    ROTOMASK: lambda filt, editable_properties:_create_rotomask_editor(filt, editable_properties),
+    COLOR_CORRECTOR: lambda filt, editable_properties, editor_name, track, clip_index: \
+                                _create_color_grader(filt, editable_properties, editor_name, track, clip_index),
+    CR_CURVES: lambda filt, editable_properties, editor_name, track, clip_index: \
+                                _create_crcurves_editor(filt, editable_properties, editor_name, track, clip_index),
+    COLOR_BOX: lambda filt, editable_properties, editor_name, track, clip_index: \
+                                _create_colorbox_editor(filt, editable_properties, editor_name, track, clip_index),
+    COLOR_LGG: lambda filt, editable_properties, editor_name, track, clip_index: \
+                                _create_color_lgg_editor(filt, editable_properties, editor_name, track, clip_index),
+    ROTOMASK: lambda filt, editable_properties, editor_name, track, clip_index: \
+                                _create_rotomask_editor(filt, editable_properties, editor_name, track, clip_index),
+    FILTER_ROTATION_GEOM_EDITOR: lambda filt, editable_properties, editor_name, track, clip_index: \
+                                _create_filter_roto_geom_editor(filt, editable_properties,  editor_name, track, clip_index),
+    INFOANDTIPS: lambda filt, editable_properties, editor_name, track, clip_index: \
+                                _create_infotips_editor(filt, editable_properties, editor_name, track, clip_index),
+    ANALYZE_STABILIZE: lambda filt, editable_properties, editor_name, track, clip_index: \
+                                _create_anylaze_stabile_editor(filt, editable_properties, editor_name, track, clip_index),
+    ANALYZE_MOTION: lambda filt, editable_properties, editor_name, track, clip_index: \
+                                _create_anylaze_motion_editor(filt, editable_properties, editor_name, track, clip_index),
+    APPLY_MOTION: lambda filt, editable_properties, editor_name, track, clip_index: \
+                                _create_apply_motion_editor(filt, editable_properties, editor_name, track, clip_index),
+    APPLY_FILTER_MASK_MOTION: lambda filt, editable_properties, editor_name, track, clip_index: \
+                                _create_apply_filter_mask_motion_editor(filt, editable_properties, editor_name, track, clip_index),
     TEXT_ENTRY: lambda ep: _get_text_entry(ep),
+    NO_KF_RECT: lambda ep : _get_no_kf_rect_geom_editor(ep),
     FILTER_RECT_GEOM_EDITOR: lambda ep : _get_filter_rect_geom_editor(ep)
     }
 
