@@ -325,7 +325,15 @@ def load_filters_translations():
     filter_names["Blend Mode"] = _("Blend Mode")
     filter_names["Unpremultiply"] = _("Unpremultiply")
     filter_names["Fade To Black In / Out"] = _("Fade To Black In / Out")
-    
+    filter_names["Elastic"] = _("Elastic")
+    filter_names["Rubberband Octave Shift"] = _("Rubberband Octave Shift")
+    filter_names["Rubberband Pitch Scale"] = _("Rubberband Pitch Scale")
+    filter_names["Image Luma"] =  _("Image Luma")
+    filter_names["Image Alpha"] = _("Image Alpha")
+    filter_names["Stabilize"] = _("Stabilize")
+    filter_names["Motion Tracking Apply"] = _("Motion Tracking Apply")
+    filter_names["Motion Tracking Create"] = _("Motion Tracking Create")
+    filter_names["Alpha Shape Motion Tracked"]= _("Alpha Shape Motion Tracked")
     # param names
     global param_names
 
@@ -687,6 +695,29 @@ def load_filters_translations():
     param_names["Reveal Right"] = _("Reveal Right")
     param_names["Fade In Type"] = _("Fade In Type")
     param_names["Image"] = _("Image")
+    param_names["RMP-peak"] = _("RMP-peak")
+    param_names["Relese(ms)"] = _("Relese(ms)")
+    param_names["Ratio"] = _("Ratio")
+    param_names["Knee Radius(dB)"] = _("Knee Radius(dB)")
+    param_names["Makeup gain(dB)"] = _("Makeup gain(dB)")
+    param_names["Velocity"] = _("Velocity")
+    param_names["Center"] = _("Center")
+    param_names["Width"] = _("Width")
+    param_names["Linear Scale"] = _("Linear Scale")
+    param_names["Non-Linear Scale"] = _("Non-Linear Scale")
+    param_names["Latency ms"] = _("Latency ms")
+    param_names["Stretch"] = _("Stretch")
+    param_names["Pitch Scale"] = _("Pitch Scale")
+    param_names["Octave Shift"] = _("Octave Shift")
+    param_names["Keyframe Step"] = _("Keyframe Step")
+    param_names["Algorithm"] = _("Algorithm")
+    param_names["X Offset"] = _("X Offset")
+    param_names["Y Offset"] = _("Y Offset")
+    param_names["Scale %"] = _("Scale %")
+    param_names["Smoothing"] = _("Smoothing")
+    param_names["Analysis Accuracy"] = _("Analysis Accuracy")
+    param_names["Analysis Shakiness"] = _("Analysis Shakiness")
+    param_names["Tracking Coords Interpretation"] = _("Tracking Coords Interpretation")
 
     # Combo options
     global combo_options
@@ -830,7 +861,11 @@ def load_filters_translations():
     combo_options["XDiagonal"] = _("XDiagonal")
     combo_options["Left"] = _("Left")
     combo_options["Right"] = _("Right")
-    
+    combo_options["Absolute"] = _("Absolute")
+    combo_options["Top Left Justified"] = _("Top Left Justified")
+    combo_options["Not Scaled"] = _("Not Scaled")
+    combo_options["Scaled To Box"] = _("Scaled To Box")
+
     # Added for 2.10
     global plugin_groups
     plugin_groups["Backgrounds"] = _("Backgrounds")
