@@ -38,6 +38,7 @@ import editorlayout
 import editorpersistance
 import editorstate
 import gui
+import guipopover
 import guiutils
 import modesetting
 import projectdata
@@ -65,25 +66,22 @@ _TOOLS_DATA = None
 _TOOL_TIPS = None
 _PREFS_TOOL_TIPS = None
 
-_tools_menu = Gtk.Menu()
-
-
 # Tool items in dock if used.
 dock_items = None
 
 def init_data():
     global _TOOLS_DATA, _TOOL_TIPS, _PREFS_TOOL_TIPS
-    _TOOLS_DATA = { appconsts.TLINE_TOOL_INSERT:        (_("Insert"), "insertmove_cursor.png"),
-                    appconsts.TLINE_TOOL_OVERWRITE:     (_("Move"), "overwrite_cursor.png"),
-                    appconsts.TLINE_TOOL_TRIM:          (_("Trim"), "oneroll_cursor.png"),                   # DEPRECATED; NOT AVAILABLE TO USERS ANYMORE.
-                    appconsts.TLINE_TOOL_ROLL:          (_("Roll"), "tworoll_cursor.png"),                   # DEPRECATED; NOT AVAILABLE TO USERS ANYMORE.
-                    appconsts.TLINE_TOOL_SLIP:          (_("Slip"), "slide_cursor.png"),                     # DEPRECATED; NOT AVAILABLE TO USERS ANYMORE.
-                    appconsts.TLINE_TOOL_SPACER:        (_("Spacer"), "multimove_cursor.png"),
-                    appconsts.TLINE_TOOL_BOX:           (_("Box"), "overwrite_cursor_box.png"),              # DEPRECATED; NOT AVAILABLE TO USERS ANYMORE.
-                    appconsts.TLINE_TOOL_RIPPLE_TRIM:   (_("Ripple Trim"), "oneroll_cursor_ripple.png"),     # DEPRECATED; NOT AVAILABLE TO USERS ANYMORE.
-                    appconsts.TLINE_TOOL_CUT:           (_("Cut"), "cut_cursor.png"),
-                    appconsts.TLINE_TOOL_KFTOOL:        (_("Keyframe"), "kftool_cursor.png"),
-                    appconsts.TLINE_TOOL_MULTI_TRIM:    (_("Multitrim"), "multitrim_cursor.png")
+    _TOOLS_DATA = { appconsts.TLINE_TOOL_INSERT:        (_("Insert"), "insertmove_cursor.png", "editools.insert"),
+                    appconsts.TLINE_TOOL_OVERWRITE:     (_("Move"), "overwrite_cursor.png", "editools.overwrite"),
+                    appconsts.TLINE_TOOL_TRIM:          (_("Trim"), "oneroll_cursor.png", "editools.trim"),                         # DEPRECATED; NOT AVAILABLE TO USERS ANYMORE.
+                    appconsts.TLINE_TOOL_ROLL:          (_("Roll"), "tworoll_cursor.png", "editools.roll"),                         # DEPRECATED; NOT AVAILABLE TO USERS ANYMORE.
+                    appconsts.TLINE_TOOL_SLIP:          (_("Slip"), "slide_cursor.png", "editools.slip"),                           # DEPRECATED; NOT AVAILABLE TO USERS ANYMORE.
+                    appconsts.TLINE_TOOL_SPACER:        (_("Spacer"), "multimove_cursor.png", "editools.spacer"),
+                    appconsts.TLINE_TOOL_BOX:           (_("Box"), "overwrite_cursor_box.png", "editools.box"),                     # DEPRECATED; NOT AVAILABLE TO USERS ANYMORE.
+                    appconsts.TLINE_TOOL_RIPPLE_TRIM:   (_("Ripple Trim"), "oneroll_cursor_ripple.png", "editools.rippletrim"),     # DEPRECATED; NOT AVAILABLE TO USERS ANYMORE.
+                    appconsts.TLINE_TOOL_CUT:           (_("Cut"), "cut_cursor.png", "editools.cut"),
+                    appconsts.TLINE_TOOL_KFTOOL:        (_("Keyframe"), "kftool_cursor.png", "editools.kftool"),
+                    appconsts.TLINE_TOOL_MULTI_TRIM:    (_("Multitrim"), "multitrim_cursor.png", "editools.multitrim")
                   }
                   
     _TOOL_TIPS =  { appconsts.TLINE_TOOL_INSERT:        _("<b>Left Mouse</b> to move and insert single clip between clips.\n<b>CTRL + Left Mouse</b> to select and move clip range.\n\n<b>Left Mouse</b> on clip ends to trim clip length."),
@@ -95,7 +93,7 @@ def init_data():
                     appconsts.TLINE_TOOL_BOX:           _("<b>1. Left Mouse</b> to draw a box to select a group of clips.\n<b>2. Left Mouse</b> inside the box to move selected clips forward or backward."), 
                     appconsts.TLINE_TOOL_RIPPLE_TRIM:   _("<b>Left Mouse</b> to trim closest clip end and move all clips after it to maintain sync, overwrites not allowed.\n<b>Left or Right Arrow Key</b> + <b>Enter Key</b> to do the edit using keyboard."), 
                     appconsts.TLINE_TOOL_CUT:           _("<b>Left Mouse</b> to cut clip under cursor.\n<b>CTRL + Left Mouse</b> to cut clips on all tracks at cursor position."), 
-                    appconsts.TLINE_TOOL_KFTOOL:        _("Click <b>Left Mouse</b> on Clip to init Volume Keyframe editing, Brightness for media with no audio data.\nUse Hamburger menu to select other values to edit.\n<b>Left Mouse</b> to create or drag keyframes.\n<b>Left Mouse + Control</b> between keyframes drag and set same value for both.\n<b>Delete Key</b> to delete active Keyframe."),
+                    appconsts.TLINE_TOOL_KFTOOL:        _("Click <b>Left Mouse</b> on Clip to init Volume Keyframe editing, Brightness for media with no audio data.\nUse Hamburger menu to select other values to edit.\n<b>Left Mouse</b> to create or drag keyframes.\n<b>Left Mouse + Control</b> between keyframes drag and set same value for both.\n<b>Left Mouse + Shift</b> moves all keyframes after selected keyframe.\n<b>Delete Key</b> to delete active Keyframe."),
                     appconsts.TLINE_TOOL_MULTI_TRIM:    _("Position cursor near or on clip edges for <b>Trim</b> and <b>Roll</b> edits.\nPosition cursor on clip center for <b>Slip</b> edit.\nDrag with <b>Left Mouse</b> to do edits.\n\n<b>Enter Key</b> to start keyboard edit, <b>Left or Right Arrow Key</b> to move edit point.\n<b>Enter Key</b> to complete keyboard edit.")
                   }
 
@@ -108,7 +106,7 @@ def get_tline_tool_working_set():
     
     kb_shortcut_number = 1
     for tool_id in editorpersistance.prefs.active_tools:
-        tool_name, tool_icon_file = _TOOLS_DATA[tool_id]
+        tool_name, tool_icon_file, action_item_id = _TOOLS_DATA[tool_id]
         tools.append((tool_name, kb_shortcut_number))
 
         kb_shortcut_number = kb_shortcut_number + 1
@@ -117,28 +115,16 @@ def get_tline_tool_working_set():
     
 # --------------------------------------------------------------- tools menu
 def get_tline_tool_popup_menu(event, callback):
-    menu = _tools_menu
-    guiutils.remove_children(menu)
-
-    menu.set_accel_group(gui.editor_window.accel_group)
-    menu.set_take_focus(False)
-    menu_items = []
+    toolsdata = []
     
     kb_shortcut_number = 1
     for tool_id in editorpersistance.prefs.active_tools:
-        tool_name, tool_icon_file = _TOOLS_DATA[tool_id]
-
-        menu_item = _get_image_menu_item(tool_icon_file, tool_name, callback, tool_id)
-        accel_path = "<Actions>/WindowActions/TOOL_ACTION_KEY_" + str(kb_shortcut_number)
-        menu_item.set_accel_path(accel_path)
-        menu.add(menu_item)
-        menu_items.append(menu_item)
-        kb_shortcut_number = kb_shortcut_number + 1
-
-    menu.connect("hide", lambda w : _tools_menu_hidden(w, menu_items))
-    menu.show_all()
-    menu.popup(None, None, None, None, event.button, event.time)
-
+        tool_name, tool_icon_file, action_item_id = _TOOLS_DATA[tool_id]
+        toolpopover_data = (tool_name, tool_icon_file, action_item_id, tool_id, _get_tooltip_text(tool_id))
+        toolsdata.append(toolpopover_data)
+            
+    guipopover.edittools_popover_custom_show(gui.editor_window.tool_selector, toolsdata, gui.editor_window.tool_selector.widget, callback)
+    
 def _tools_menu_hidden(tools_menu, menu_items):
     # needed to make number 1-9 work elsewhere in the application
     for menu_item in menu_items:
@@ -157,150 +143,12 @@ def _get_image_menu_item(tool_icon_file, text, callback, tool_id):
         item.set_tooltip_markup(_get_tooltip_text(tool_id))
     item.show()
     return item
-"""
-# ---------------------------------------------------- workflow menu
-def workflow_menu_launched(widget, event):
-    guiutils.remove_children(_workflow_menu)
 
-    standard = guiutils.get_menu_item(_("Reset Tools"), _workflow_menu_callback, (None, "preset standard"))
-    standard.show()
-    _workflow_menu.add(standard)
-
-    show_tooltips_item = Gtk.CheckMenuItem()
-    show_tooltips_item.set_label(_("Show Tooltips for Edit Tools"))
-    show_tooltips_item.set_active(editorpersistance.prefs.show_tool_tooltips)
-    show_tooltips_item.connect("activate", _workflow_menu_callback, (None, "tooltips"))
-    show_tooltips_item.show()
-    _workflow_menu.append(show_tooltips_item)
-
-    # --- tools
-    guiutils.add_separetor(_workflow_menu)
-    
-    # Active tools
-    non_active_tools = list(range(1, 12)) # we have 11 tools currently
-    for i in range(0, len(editorpersistance.prefs.active_tools)):#  tool_id in _TOOLS_DATA:
-        tool_id = editorpersistance.prefs.active_tools[i]
-        tool_name, tool_icon_file = _TOOLS_DATA[tool_id]
-        _workflow_menu.add(_get_workflow_tool_menu_item(_workflow_menu_callback, tool_id, tool_name, tool_icon_file, i+1))
-        try: # needed to prevent crashes when manually changing preset tools during development.
-            non_active_tools.remove(tool_id)
-        except:
-            pass
-
-    guiutils.add_separetor(_workflow_menu)
-    
-    # Non-active tools
-    for tool_id in non_active_tools:
-        tool_name, tool_icon_file = _TOOLS_DATA[tool_id]
-        _workflow_menu.add(_get_workflow_tool_menu_item(_workflow_menu_callback, tool_id, tool_name, tool_icon_file, -1))
-        
-    _workflow_menu.popup(None, None, None, None, event.button, event.time)
-
-def _get_workflow_tool_menu_item(callback, tool_id, tool_name, tool_icon_file, position):
-
-    tool_img = Gtk.Image.new_from_file(respaths.IMAGE_PATH + tool_icon_file)
-    tool_name_label = Gtk.Label(tool_name)
-    
-    hbox = Gtk.HBox()
-    hbox.pack_start(guiutils.pad_label(4, 4), False, False, 0)
-    hbox.pack_start(tool_img, False, False, 0)
-    hbox.pack_start(guiutils.pad_label(4, 4), False, False, 0)
-    hbox.pack_start(tool_name_label, False, False, 0)
-    hbox.show_all()
-    item = Gtk.MenuItem()
-    item.add(hbox)
-    if editorpersistance.prefs.show_tool_tooltips:
-        item.set_tooltip_markup(_get_tooltip_text(tool_id))
-    item.show()
-    
-    item.set_submenu(_get_workflow_tool_submenu(callback, tool_id, position))
-
-    return item
-
-def _build_radio_menu_items_group(menu, labels, msgs, callback, active_index):
-    first_item = Gtk.RadioMenuItem()
-    first_item.set_label(labels[0])
-    first_item.show()
-    menu.append(first_item)
-    if active_index == 0:
-        first_item.set_active(True)
-    first_item.connect("activate", callback, (None,msgs[0]))
-    
-    for i in range(1, len(labels)):
-        radio_item = Gtk.RadioMenuItem.new_with_label([first_item], labels[i])
-        menu.append(radio_item)
-        radio_item.show()
-        if active_index == i:
-            radio_item.set_active(True)
-        
-        radio_item.connect("activate", callback, (None, msgs[i]))
-"""
 def _get_tooltip_text(tool_id):
     text = _TOOL_TIPS[tool_id]
 
     return text
-"""
-def _get_workflow_tool_submenu(callback, tool_id, position):
-    sub_menu = Gtk.Menu()
-    
-    tool_active = (tool_id in editorpersistance.prefs.active_tools)
-    activity_item = Gtk.CheckMenuItem(_("Edit Tool Active"))
-    activity_item.set_active(tool_active)
-    activity_item.connect("toggled", callback, (tool_id, "activity"))
-    activity_item.show()
-    sub_menu.add(activity_item)
 
-    guiutils.add_separetor(sub_menu)
-    
-    position_item = Gtk.MenuItem.new_with_label(_("Set Position"))
-    if tool_active == False:
-        position_item.set_sensitive(False)
-    position_item.show()
-
-    position_menu = Gtk.Menu()
-    
-    for i in range(1, len(editorpersistance.prefs.active_tools) + 1):
-        move_to_position_item = guiutils.get_menu_item(str(i), _workflow_menu_callback, (tool_id, str(i)))
-        if i == position or position == -1:
-            move_to_position_item.set_sensitive(False)
-        move_to_position_item.show()
-        position_menu.add(move_to_position_item)
-        
-    position_item.set_submenu(position_menu)
-
-    sub_menu.add(position_item)
-    
-    return sub_menu
-    
-def _workflow_menu_callback(widget, data):
-    tool_id, msg = data
-    
-    if msg == "activity":
-        if widget.get_active() == False:
-            editorpersistance.prefs.active_tools.remove(tool_id)
-        else:
-            editorpersistance.prefs.active_tools.append(tool_id)
-        update_tool_dock()
-    elif  msg == "always overwrite":
-        editorpersistance.prefs.dnd_action = appconsts.DND_ALWAYS_OVERWRITE
-    elif  msg == "overwrite nonV1":
-        editorpersistance.prefs.dnd_action = appconsts.DND_OVERWRITE_NON_V1
-    elif  msg == "always insert":
-        editorpersistance.prefs.dnd_action = appconsts.DND_ALWAYS_INSERT
-    elif  msg == "tooltips":
-        editorpersistance.prefs.show_tool_tooltips = widget.get_active()
-    else:
-        try: # Set tool position
-            pos = int(msg)
-            current_index = editorpersistance.prefs.active_tools.index(tool_id)
-            editorpersistance.prefs.active_tools.remove(tool_id)
-            editorpersistance.prefs.active_tools.insert(pos - 1, tool_id)
-            update_tool_dock()
-        except:
-            pass
-    
-    editorpersistance.save()
-"""
 
 # ---------------------------------------------------- tools dock
 def get_tline_tool_dock():
@@ -309,7 +157,7 @@ def get_tline_tool_dock():
     dock_items = []
     kb_shortcut_number = 1
     for tool_id in editorpersistance.prefs.active_tools:
-        tool_name, tool_icon_file = _TOOLS_DATA[tool_id]
+        tool_name, tool_icon_file, action_item_id = _TOOLS_DATA[tool_id]
 
         dock_item = _get_tool_dock_item(kb_shortcut_number, tool_icon_file, tool_name, tool_id)
         dock.pack_start(dock_item.widget, False, False, 0)
@@ -339,7 +187,7 @@ def _tool_dock_item_press(tool_id, tool_dock_item):
     for item in dock_items:
         item.set_item_color(False)
     tool_dock_item.set_item_color(True)
-    gui.editor_window.tline_cursor_manager.tool_selector_item_activated(None, tool_id)
+    gui.editor_window.tline_cursor_manager.tool_selector_item_activated(None, None, tool_id)
 
 def set_default_tool_dock_item_selected():
     for item in dock_items:
@@ -366,7 +214,9 @@ class ToolDockItem:
         if selected == True:
             self.widget.override_background_color(Gtk.StateType.NORMAL, SELECTED_BG)
         else:
-            self.widget.override_background_color(Gtk.StateType.NORMAL, gui.get_bg_color())
+            color = Gdk.RGBA(red=1.0, green=1.0, blue=1.0, alpha=1.0)
+            color.parse("#292929")
+            self.widget.override_background_color(Gtk.StateType.NORMAL, color)
 
 
 # ------------------------------------------------------------- keyboard shortcuts
