@@ -41,7 +41,7 @@ flowblade_package_data = ['res/filters/*.xml','res/filters/wipes/*','res/img/*',
                           'res/mediaplugins/*', 'res/mediaplugins/animations_1/*',
                           'res/mediaplugins/animations_2/*', 'res/mediaplugins/text_1/*',
                           'res/mediaplugins/text_2/*', 'res/mediaplugins/transitions_1/*',
-                          'res/mediaplugins/transitions_2/*','res/gpu-test/*','res/scripttool/*']
+                          'res/mediaplugins/transitions_2/*','res/gpu-test/*','res/scripttool/*', 'res/usbhid/*']
 
 locale_files = []
 for filepath in glob.glob("Flowblade/locale/*/LC_MESSAGES/*"):
@@ -49,7 +49,7 @@ for filepath in glob.glob("Flowblade/locale/*/LC_MESSAGES/*"):
     locale_files.append(filepath)
 
 setup(  name='flowblade',
-        version='2.12.0.2',
+        version='2.16.3',
         author='Janne Liljeblad',
         author_email='janne.liljeblad at gmail dot com',
         description='Non-linear video editor',
